package DBIx::Class::Storage::DBI::ODBC::Microsoft_SQL_Server;
use strict;
use warnings;

use base qw/DBIx::Class::Storage::DBI::ODBC/;

sub _dbh_last_insert_id {
    my ($self, $dbh, $source, $col) = @_;

    my $sth = $dbh->prepare_cached('SELECT SCOPE_IDENTITY()', {}, 3);
    $sth->execute();

    my @res = $sth->fetchrow_array();

    return @res ? $res[0] : undef;
}

sub _sql_maker_opts {
    my ($self) = @_;
    
    $self->dbh_do(sub {
        return { limit_dialect => 'Top' };
    });
}

1;

__END__

=head1 NAME

DBIx::Class::Storage::ODBC::Microsoft_SQL_Server - Support specific to
Microsoft SQL Server over ODBC

=head1 SYNOPSIS

  # In your table classes
  __PACKAGE__->load_components(qw/Core/);
  __PACKAGE__->set_primary_key('id');


=head1 DESCRIPTION

This class implements support specific to Microsoft SQL Server over ODBC,
including auto-increment primary keys and SQL::Abstract::Limit dialect.


=head1 AUTHORS

Marc Mims C<< <marc@questright.com> >>

=head1 LICENSE

You may distribute this code under the same terms as Perl itself.

=cut
